<?php

/**
 * Class for Admin Notifications.
 *
 * @package Terms_And_Conditions_Per_Product
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// If class exists, then don't execute this.
if ( ! class_exists( 'TACPP4_Terms_Conditions_Admin_Notices' ) ) {
    class TACPP4_Terms_Conditions_Admin_Notices {
        public string $seen_notices_option_name = 'tacpp_seen_notices';

        public function __construct() {
            add_action( 'admin_notices',
                array( $this, 'show_admin_notices' ) );

            add_action( 'wp_ajax_tacpp_hide_notice',
                array( $this, 'tacpp_hide_notice' ) );
        }

        /**
         * Returns an array of TACPP admin notices.
         *
         * @return mixed
         */
        public function get_admin_notices() {
            $admin_notices = array(
                'tacpp-premium-notice' => array(
                    'text'     => sprintf( __( 'Terms and Conditions per product now have a <a href=%s target="_blank">premium version</a> that allows <strong>terms and conditions per product category</strong> as well as opening the terms in a <strong>modal</strong>.', 'terms-and-conditions-per-product' ), esc_html( 'https://tacpp-pro.com/' ) ),
                    'user_cap' => 'activate_plugins',
                    'is_free'  => true,
                ),
            );

            return apply_filters( 'tacpp4_terms_conditions_admin_notices_get_admin_notices',
                $admin_notices );
        }

        /**
         * Show admin notices.
         */
        public function show_admin_notices() {
            $admin_notices = $this->get_admin_notices();

            if ( ! empty( $admin_notices ) ) {

                $seen_notices = $this->get_seen_notices();

                foreach ( $admin_notices as $notice_id => $notice ) {
                    // Skip for paid users
                    if ( $notice['is_free'] && tacppp_fs()->is_paying_or_trial() ) {
                        continue;
                    } // Skip for free users
                    else if ( ! $notice['is_free'] && ! tacppp_fs()->is_paying_or_trial() ) {
                        continue;
                    }

                    // Skip if notice is already seen
                    if ( in_array( $notice_id, $seen_notices ) ) {
                        continue;
                    }


                    $this->show_admin_notice( $notice['text'], $notice_id );
                }
            }
        }



        /**
         * HTML for admin notice.
         *
         * @param        $notice
         * @param string $notice_id
         */
        public function show_admin_notice( $notice, $notice_id = '' ) {
            ?>
			<div id="<?php echo esc_html( $notice_id ); ?>" class="tacpp-admin-notice notice notice-success is-dismissible">
				<p><?php echo $notice; ?></p>
			</div>
            <?php
        }

        /**
         * Ajax callback to hide admin notices.
         */
        public function tacpp_hide_notice() {
            $nonce     = sanitize_text_field( $_POST['nonce'] );
            $notice_id = sanitize_text_field( $_POST['noticeID'] );

            // Security Validate Nonce
            if ( ! wp_verify_nonce( $nonce, 'tacpp-ajax-nonce' ) ) {
                $response['success'] = false;
                $response['content'] = 'Security check failed';
                echo json_encode( $response );
                wp_die();
            }

            // Check Notice ID
            if ( $notice_id <= 0 ) {
                $response['success'] = false;
                $response['content'] = 'No notice ID';
                echo json_encode( $response );
                wp_die();
            }

            // Update hidden notices
            $this->update_seen_notices( $notice_id );

            $response['success'] = true;
            $response['content'] = 'Notice hidden';
            echo json_encode( $response );
            wp_die();

        }

        /**
         * Get an array of all seen notice IDs
         *
         * @return mixed
         */

        public function get_seen_notices() {
            $notices = (array) get_user_meta( get_current_user_id(), $this->seen_notices_option_name, true );

            $notices = array_filter( $notices );

            return apply_filters( 'tacpp4_terms_conditions_get_seen_notices',
                $notices );
        }

        /**
         * Update seen notices in DB so they do not appear again
         *
         * @param $notice_id
         */
        public function update_seen_notices( $notice_id ) {
            $notice_id    = sanitize_text_field( $notice_id );
            $seen_notices = $this->get_seen_notices();

            // Add notice to hidden notices
            if ( ! in_array( $notice_id, $seen_notices ) ) {
                $seen_notices[] = $notice_id;
            }

            $seen_notices = array_filter( $seen_notices );

            // Update DB option
            update_user_meta(
                get_current_user_id(),
                $this->seen_notices_option_name,
                $seen_notices
            );
        }

    }

    new TACPP4_Terms_Conditions_Admin_Notices();
}
