<?php
/**
 * Class for Terms and Conditions per Product Settings.
 *
 * @package Terms_And_Conditions_Per_Product
 */

/**
 * Exit if accessed directly.
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// If class exists, then don't execute this.
if ( ! class_exists( 'TACPP4_Terms_Conditions_Settings' ) ) {

    /**
     * Class
     */
    class TACPP4_Terms_Conditions_Settings {

        protected static $instance = null;

        static $tacpp_option_name;

        public static function get_instance() {
            null === self::$instance and self::$instance = new self;

            return self::$instance;
        }


        /**
         * Constructor for class.
         */
        public function __construct() {
            self::$tacpp_option_name = 'tacpp_admin_settings';

            if ( is_admin() ) {
                add_action( 'admin_menu',
                    array( __CLASS__, 'add_settings_menu_entry' ), 100 );
                add_action( 'admin_init', array( $this, 'update_settings' ) );

                add_filter( 'woocommerce_admin_field_full_info',
                    array( $this, 'show_setting_info' ) );

                add_action( 'admin_enqueue_scripts', array( &$this, 'admin_enqueue_scripts' ) );
            }
        }

        public function admin_enqueue_scripts() {
            // Custom plugin script.
            wp_enqueue_style(
                'terms-per-product-admin-settings',
                TACPP4_PLUGIN_URL . 'assets/css/terms-admin-settings.css',
                '',
                TACPP4_PLUGIN_VERSION
            );
        }

        public static function add_settings_menu_entry() {
            add_menu_page(
                __( 'Terms and Conditions', 'terms-and-conditions-per-product' ),
                __( 'Terms of Use', 'terms-and-conditions-per-product' ),
                'manage_woocommerce', // Required user capability
                'tacpp',
                array( __CLASS__, 'tacpp_submenu_tacpp_page_callback' ),
                TACPP4_PLUGIN_URL . '/assets/images/avatar.svg'
            );

            add_submenu_page(
                "tacpp",
                __( 'Settings', 'terms-and-conditions-per-product' ),
                __( 'Settings', 'terms-and-conditions-per-product' ),
                'manage_woocommerce',
                "tacpp_settings",
                array( __CLASS__, 'tacpp_submenu_settings_page_callback' )
            );

        }

        public static function tacpp_submenu_settings_page_callback() {
            $template = apply_filters(
                'tacpp_submenu_settings_page_template',
                TACPP4_PLUGIN_PATH . 'templates/admin-settings-page.php'
            );

            include( $template );
        }

        public static function tacpp_submenu_tacpp_page_callback() {
            $template = apply_filters(
                'tacpp_submenu_tacpp_page_callback',
                TACPP4_PLUGIN_PATH . 'templates/admin-tacpp-page.php'
            );

            include( $template );
        }

        private static function get_settings() {

            $settings = get_option( self::$tacpp_option_name );

            // Set checkbox value to yes in order to be checked
            $terms_modal_value = '';
            if ( isset( $settings['terms_modal'] ) && $settings['terms_modal'] === 1 ) {
                $terms_modal_value = 'yes';
            }

            $settings = array(
                'section_title' => array(
                    'name' => __( 'Configure Terms and Conditions per Product',
                        'terms-and-conditions-per-product' ),
                    'type' => 'title',
                    'desc' => '',
                    'id'   => 'tacpp_settings_section_title'
                ),
                'terms_modal'   => array(
                    'name'  => __( 'Open product terms in a modal',
                        'terms-and-conditions-per-product' ),
                    'type'  => 'checkbox',
                    'id'    => 'tacpp_terms_in_modal',
                    'value' => $terms_modal_value,
                ),
            );

            if ( ! tacppp_fs()->is_paying_or_trial() ) {

                $text = sprintf( __( 'Get the <a href="%s">premium version</a> now!', 'terms-and-conditions-per-product' ),
                    TACPP4_PLUGIN_PRO_BUY_URL
                );

                $settings['terms_modal']             = array(
                    'name'              => __( 'Open product terms in a modal [Premium]',
						'terms-and-conditions-per-product' ),
                    'type'              => 'checkbox',
                    'id'                => 'tacpp_terms_in_modal',
                    'value'             => 0,
                    'class'             => 'disabled',
                    'custom_attributes' => array( 'disabled' => 'disabled' ),
                );
                $settings['terms_modal_get_premium'] = array(
                    'type' => 'full_info',
                    'id'   => 'tacpp_terms_in_modal_get_premium',
                    'text' => $text,
                );
            }

            $settings['section_end'] = array(
                'type' => 'sectionend',
                'id'   => 'tacpp_settings_section_end'
            );

            return apply_filters( 'tacpp_admin_settings_form', $settings );
        }

        /**
         * Store TACPP settings to DB
         */
        public function update_settings() {
            if ( ! isset( $_GET['page'] ) || $_GET['page'] !== 'tacpp_settings' || ! $_POST ) {
                return;
            }
            $settings = get_option( self::$tacpp_option_name );

            $settings['terms_modal'] = ( isset( $_POST['tacpp_terms_in_modal'] ) ? 1 : 0 );

            update_option( self::$tacpp_option_name, $settings );

        }

        public function show_setting_info( $settings ) {
            ?>
			<tr>
				<th scope="row" class="" colspan="2">
                    <?php echo wp_kses_post( wpautop( wptexturize( $settings['text'] ) ) ); ?>
				</td></tr>
            <?php
        }
    }

    new TACPP4_Terms_Conditions_Settings();
}
